@@ -6,6 +6,8 @@ from jinja2.loaders import FileSystemLoader
 from jinja2 import Environment
 from hipsaint.options import COLORS
 
+log = logging.getLogger(__name__)
+
 
 class HipchatMessage(object):
     url = "https://api.hipchat.com/v1/rooms/message"
@@ -19,7 +21,7 @@ class HipchatMessage(object):
         self.room_id = room_id
         self.notify = notify
 
-    def deliver_payload(self):
+    def deliver_payload(self, **kwargs):
         """ Makes HTTP GET request to HipChat containing the message from nagios
             according to API Documentation https://www.hipchat.com/docs/api/method/rooms/message
         """
@@ -30,15 +32,17 @@ class HipchatMessage(object):
                    'color': self.message_color,
                    'notify': int(self.notify),
                    'auth_token': self.token}
+        message.update(kwargs)
         raw_response = requests.get(self.url, params=message)
-        response_data = raw_response.json
+        response_data = raw_response.json()
         if 'error' in response_data:
             error_message = response_data['error'].get('message')
             error_type = response_data['error'].get('type')
             error_code = response_data['error'].get('code')
-            logging.error('%s - %s: %s' % (error_code, error_type, error_message))
+            log.error('%s - %s: %s', error_code, error_type, error_message)
         elif not 'status' in response_data:
-            logging.error('Unexpected response')
+            log.error('Unexpected response')
+        return raw_response
 
     def render_message(self):
         """ Unpacks Nagios inputs and renders the appropriate template depending
